#! /usr/bin/python

# Script used to create verticalbar.png files
# To run, simply do
#
# ./create_verticalbarpng.py

import zlib, sys, struct

def create_png_image(width, height, red, green, blue):
    assert(red >= 0 and red < 256)
    assert(green >= 0 and green < 256)
    assert(blue >= 0 and blue < 256)
    assert(width > 0 and width < 256)
    assert(height > 0 and height < 256)

    pngheader = struct.pack("BBBBBBBB", 137, 80, 78, 71, 13, 10, 26, 10)
    ihdrlen = struct.pack("BBBB", 0, 0, 0, 13)
    ihdr = struct.pack("ccccBBBBBBBBBBBBB", 
                       "I", "H", "D", "R",
                       0, 0, 0, width, 
                       0, 0, 0, height,
                       8, 2, 0, 0, 0) 
    ihdrcrc = struct.pack(">I", zlib.crc32( ihdr ))

    idatlen = struct.pack(">I", width*height*3 + height + 7 + 4 )
    idat = struct.pack("cccc", "I", "D", "A", "T")

    pix = chr(red) + chr(green) + chr(blue)
    pixdark = chr(red*2/3) + chr(green*2/3) + chr(blue*2/3)
    data = ""
    for h in range(0, height):
        data += chr(0)
        for w in range(0, width):
            if (w < width * 3/4):
                data += pix
            else:
                data += pixdark
    data = zlib.compress(data, 0)
    idatcrc = struct.pack(">I", zlib.crc32( idat + data ))

    iendlen = struct.pack("BBBB", 0, 0, 0, 0)
    iend = struct.pack("cccc", "I", "E", "N", "D")
    iendcrc = struct.pack(">I", zlib.crc32(iend)) 

    result = pngheader + ihdrlen + ihdr + ihdrcrc + \
                         idatlen + idat + data + idatcrc + \
                         iendlen + iend + iendcrc
    return result



colors = [ "", "FFFF96", "40C880", "80A0FF", "A080FF" ]
width = height = 12
for i in range(1,5):
    out = open("verticalbar" + str(i) + ".png", "w")
    c = colors[i]
    red = int(c[0:2], 16)
    green = int(c[2:4], 16)
    blue = int(c[4:6], 16)
    data = create_png_image(width, height, red, green, blue)
    out.write(data)
    out.close()

